from pathlib import Path
from typing import Optional
from urllib import parse

import click

import vessl
from vessl import vessl_api
from vessl.util.echo import print_info, print_success, print_warning


def set_default_ssh_key(key_path: str):
    path = Path(key_path)
    if path.suffix == '.pub':
        path = path.with_suffix('')

    if path.exists():
        vessl_api.config_loader.default_ssh_private_key_path = str(path.absolute())
        print_success(f"Registered {path} as a default keyfile for vessl ssh commands.")


def ssh_command_from_endpoint(endpoint: str, key_path: Optional[str] = None) -> str:
    endpoint = parse.urlparse(endpoint)
    cmd = f"ssh root@{endpoint.hostname} -p {endpoint.port}"
    if key_path:
        cmd += f" -i {key_path}"
    return cmd


def resolve_ssh_private_key_path(key_path: Optional[str]) -> Optional[str]:
    if key_path:
        return key_path

    if default_key_path := vessl_api.config_loader.default_ssh_private_key_path:
        print_success(f"{default_key_path} found. Using this key to connect...")
        return default_key_path

    print_info("Searching for SSH private key...")
    ssh_keys = vessl.list_ssh_keys()
    if len(ssh_keys) == 0:
        raise click.BadParameter(
            "At least one ssh public key should be added.\n" "Please run `vessl ssh-key add`."
        )

    for ssh_key in ssh_keys:
        if ssh_key.filename.endswith(".pub"):
            key_path = Path.home() / ".ssh" / ssh_key.filename[:-4]
            if key_path.exists():
                print_success(f"{key_path} found. Using this key to connect...")
                return str(key_path)

    for key_path in (
        Path.home() / ".ssh" / "id_ed25519",
        Path.home() / ".ssh" / "id_rsa",
    ):
        if key_path.exists():
            print_success(f"{key_path} found. Using this key to connect...")
            return str(key_path)

    print_warning("No SSH private key found. Please provide the path to the SSH private key with --key-path option.")
    return None


def ssh_private_key_path_callback(
    ctx: click.Context, param: click.Parameter, key_path: Optional[str]
) -> Optional[str]:
    return resolve_ssh_private_key_path(key_path)



from typing import List

from vessl.llm import connection, document, knowledge


class IngestionConfig(object):
    llm_knowledge: knowledge.Knowledge
    llm_model: connection.ModelConnection
    vector_db: connection.VectorDBConnection
    documents: List[document.Document]

    def __init__(self, llm_knowledge: knowledge.Knowledge, llm_model: connection.ModelConnection, vector_db: connection.VectorDBConnection, documents: List[document.Document]):
        self.llm_knowledge = llm_knowledge
        self.llm_model = llm_model
        self.vector_db = vector_db
        self.documents = documents


# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from vessl.openapi_client.configuration import Configuration


class PersistentArtifactCreateAPIInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'artifact_name': 'str',
        'description': 'str',
        'managed_storage_configuration': 'V1ManagedStorageConfiguration',
        'nfs_storage_configuration': 'V1NFSStorageConfiguration',
        'parent_artifact_id': 'int',
        's3_storage_configuration': 'V1S3StorageConfiguration',
        'storage_type': 'str',
        'sub_path': 'str'
    }

    attribute_map = {
        'artifact_name': 'artifact_name',
        'description': 'description',
        'managed_storage_configuration': 'managed_storage_configuration',
        'nfs_storage_configuration': 'nfs_storage_configuration',
        'parent_artifact_id': 'parent_artifact_id',
        's3_storage_configuration': 's3_storage_configuration',
        'storage_type': 'storage_type',
        'sub_path': 'sub_path'
    }

    def __init__(self, artifact_name=None, description=None, managed_storage_configuration=None, nfs_storage_configuration=None, parent_artifact_id=None, s3_storage_configuration=None, storage_type='managed', sub_path=None, local_vars_configuration=None):  # noqa: E501
        """PersistentArtifactCreateAPIInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._artifact_name = None
        self._description = None
        self._managed_storage_configuration = None
        self._nfs_storage_configuration = None
        self._parent_artifact_id = None
        self._s3_storage_configuration = None
        self._storage_type = None
        self._sub_path = None
        self.discriminator = None

        self.artifact_name = artifact_name
        self.description = description
        if managed_storage_configuration is not None:
            self.managed_storage_configuration = managed_storage_configuration
        if nfs_storage_configuration is not None:
            self.nfs_storage_configuration = nfs_storage_configuration
        self.parent_artifact_id = parent_artifact_id
        if s3_storage_configuration is not None:
            self.s3_storage_configuration = s3_storage_configuration
        if storage_type is not None:
            self.storage_type = storage_type
        self.sub_path = sub_path

    @property
    def artifact_name(self):
        """Gets the artifact_name of this PersistentArtifactCreateAPIInput.  # noqa: E501


        :return: The artifact_name of this PersistentArtifactCreateAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._artifact_name

    @artifact_name.setter
    def artifact_name(self, artifact_name):
        """Sets the artifact_name of this PersistentArtifactCreateAPIInput.


        :param artifact_name: The artifact_name of this PersistentArtifactCreateAPIInput.  # noqa: E501
        :type artifact_name: str
        """

        self._artifact_name = artifact_name

    @property
    def description(self):
        """Gets the description of this PersistentArtifactCreateAPIInput.  # noqa: E501


        :return: The description of this PersistentArtifactCreateAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PersistentArtifactCreateAPIInput.


        :param description: The description of this PersistentArtifactCreateAPIInput.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def managed_storage_configuration(self):
        """Gets the managed_storage_configuration of this PersistentArtifactCreateAPIInput.  # noqa: E501


        :return: The managed_storage_configuration of this PersistentArtifactCreateAPIInput.  # noqa: E501
        :rtype: V1ManagedStorageConfiguration
        """
        return self._managed_storage_configuration

    @managed_storage_configuration.setter
    def managed_storage_configuration(self, managed_storage_configuration):
        """Sets the managed_storage_configuration of this PersistentArtifactCreateAPIInput.


        :param managed_storage_configuration: The managed_storage_configuration of this PersistentArtifactCreateAPIInput.  # noqa: E501
        :type managed_storage_configuration: V1ManagedStorageConfiguration
        """

        self._managed_storage_configuration = managed_storage_configuration

    @property
    def nfs_storage_configuration(self):
        """Gets the nfs_storage_configuration of this PersistentArtifactCreateAPIInput.  # noqa: E501


        :return: The nfs_storage_configuration of this PersistentArtifactCreateAPIInput.  # noqa: E501
        :rtype: V1NFSStorageConfiguration
        """
        return self._nfs_storage_configuration

    @nfs_storage_configuration.setter
    def nfs_storage_configuration(self, nfs_storage_configuration):
        """Sets the nfs_storage_configuration of this PersistentArtifactCreateAPIInput.


        :param nfs_storage_configuration: The nfs_storage_configuration of this PersistentArtifactCreateAPIInput.  # noqa: E501
        :type nfs_storage_configuration: V1NFSStorageConfiguration
        """

        self._nfs_storage_configuration = nfs_storage_configuration

    @property
    def parent_artifact_id(self):
        """Gets the parent_artifact_id of this PersistentArtifactCreateAPIInput.  # noqa: E501


        :return: The parent_artifact_id of this PersistentArtifactCreateAPIInput.  # noqa: E501
        :rtype: int
        """
        return self._parent_artifact_id

    @parent_artifact_id.setter
    def parent_artifact_id(self, parent_artifact_id):
        """Sets the parent_artifact_id of this PersistentArtifactCreateAPIInput.


        :param parent_artifact_id: The parent_artifact_id of this PersistentArtifactCreateAPIInput.  # noqa: E501
        :type parent_artifact_id: int
        """

        self._parent_artifact_id = parent_artifact_id

    @property
    def s3_storage_configuration(self):
        """Gets the s3_storage_configuration of this PersistentArtifactCreateAPIInput.  # noqa: E501


        :return: The s3_storage_configuration of this PersistentArtifactCreateAPIInput.  # noqa: E501
        :rtype: V1S3StorageConfiguration
        """
        return self._s3_storage_configuration

    @s3_storage_configuration.setter
    def s3_storage_configuration(self, s3_storage_configuration):
        """Sets the s3_storage_configuration of this PersistentArtifactCreateAPIInput.


        :param s3_storage_configuration: The s3_storage_configuration of this PersistentArtifactCreateAPIInput.  # noqa: E501
        :type s3_storage_configuration: V1S3StorageConfiguration
        """

        self._s3_storage_configuration = s3_storage_configuration

    @property
    def storage_type(self):
        """Gets the storage_type of this PersistentArtifactCreateAPIInput.  # noqa: E501


        :return: The storage_type of this PersistentArtifactCreateAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._storage_type

    @storage_type.setter
    def storage_type(self, storage_type):
        """Sets the storage_type of this PersistentArtifactCreateAPIInput.


        :param storage_type: The storage_type of this PersistentArtifactCreateAPIInput.  # noqa: E501
        :type storage_type: str
        """
        allowed_values = ["managed", "s3", "nfs"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and storage_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `storage_type` ({0}), must be one of {1}"  # noqa: E501
                .format(storage_type, allowed_values)
            )

        self._storage_type = storage_type

    @property
    def sub_path(self):
        """Gets the sub_path of this PersistentArtifactCreateAPIInput.  # noqa: E501


        :return: The sub_path of this PersistentArtifactCreateAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._sub_path

    @sub_path.setter
    def sub_path(self, sub_path):
        """Sets the sub_path of this PersistentArtifactCreateAPIInput.


        :param sub_path: The sub_path of this PersistentArtifactCreateAPIInput.  # noqa: E501
        :type sub_path: str
        """

        self._sub_path = sub_path

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PersistentArtifactCreateAPIInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PersistentArtifactCreateAPIInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from vessl.openapi_client.configuration import Configuration


class V1RunSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'command': 'list[V1CommandBody]',
        'env_vars': 'list[V1EnvVar]',
        'interactive': 'V1Interactive',
        'node_ids': 'list[int]',
        'ports': 'list[V1Port]',
        'resource_spec': 'V1KernelResourceSpec',
        'service_account_name': 'str',
        'start_command': 'str',
        'termination_protection': 'bool',
        'volume_claim_mounts': 'dict[str, V1VolumeClaimMount]',
        'volume_v2_mounts': 'list[V1VolumeV2Mount]'
    }

    attribute_map = {
        'command': 'command',
        'env_vars': 'env_vars',
        'interactive': 'interactive',
        'node_ids': 'node_ids',
        'ports': 'ports',
        'resource_spec': 'resource_spec',
        'service_account_name': 'service_account_name',
        'start_command': 'start_command',
        'termination_protection': 'termination_protection',
        'volume_claim_mounts': 'volume_claim_mounts',
        'volume_v2_mounts': 'volume_v2_mounts'
    }

    def __init__(self, command=None, env_vars=None, interactive=None, node_ids=None, ports=None, resource_spec=None, service_account_name=None, start_command=None, termination_protection=None, volume_claim_mounts=None, volume_v2_mounts=None, local_vars_configuration=None):  # noqa: E501
        """V1RunSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._command = None
        self._env_vars = None
        self._interactive = None
        self._node_ids = None
        self._ports = None
        self._resource_spec = None
        self._service_account_name = None
        self._start_command = None
        self._termination_protection = None
        self._volume_claim_mounts = None
        self._volume_v2_mounts = None
        self.discriminator = None

        if command is not None:
            self.command = command
        if env_vars is not None:
            self.env_vars = env_vars
        if interactive is not None:
            self.interactive = interactive
        if node_ids is not None:
            self.node_ids = node_ids
        if ports is not None:
            self.ports = ports
        if resource_spec is not None:
            self.resource_spec = resource_spec
        if service_account_name is not None:
            self.service_account_name = service_account_name
        if start_command is not None:
            self.start_command = start_command
        if termination_protection is not None:
            self.termination_protection = termination_protection
        if volume_claim_mounts is not None:
            self.volume_claim_mounts = volume_claim_mounts
        if volume_v2_mounts is not None:
            self.volume_v2_mounts = volume_v2_mounts

    @property
    def command(self):
        """Gets the command of this V1RunSpec.  # noqa: E501


        :return: The command of this V1RunSpec.  # noqa: E501
        :rtype: list[V1CommandBody]
        """
        return self._command

    @command.setter
    def command(self, command):
        """Sets the command of this V1RunSpec.


        :param command: The command of this V1RunSpec.  # noqa: E501
        :type command: list[V1CommandBody]
        """

        self._command = command

    @property
    def env_vars(self):
        """Gets the env_vars of this V1RunSpec.  # noqa: E501


        :return: The env_vars of this V1RunSpec.  # noqa: E501
        :rtype: list[V1EnvVar]
        """
        return self._env_vars

    @env_vars.setter
    def env_vars(self, env_vars):
        """Sets the env_vars of this V1RunSpec.


        :param env_vars: The env_vars of this V1RunSpec.  # noqa: E501
        :type env_vars: list[V1EnvVar]
        """

        self._env_vars = env_vars

    @property
    def interactive(self):
        """Gets the interactive of this V1RunSpec.  # noqa: E501


        :return: The interactive of this V1RunSpec.  # noqa: E501
        :rtype: V1Interactive
        """
        return self._interactive

    @interactive.setter
    def interactive(self, interactive):
        """Sets the interactive of this V1RunSpec.


        :param interactive: The interactive of this V1RunSpec.  # noqa: E501
        :type interactive: V1Interactive
        """

        self._interactive = interactive

    @property
    def node_ids(self):
        """Gets the node_ids of this V1RunSpec.  # noqa: E501


        :return: The node_ids of this V1RunSpec.  # noqa: E501
        :rtype: list[int]
        """
        return self._node_ids

    @node_ids.setter
    def node_ids(self, node_ids):
        """Sets the node_ids of this V1RunSpec.


        :param node_ids: The node_ids of this V1RunSpec.  # noqa: E501
        :type node_ids: list[int]
        """

        self._node_ids = node_ids

    @property
    def ports(self):
        """Gets the ports of this V1RunSpec.  # noqa: E501


        :return: The ports of this V1RunSpec.  # noqa: E501
        :rtype: list[V1Port]
        """
        return self._ports

    @ports.setter
    def ports(self, ports):
        """Sets the ports of this V1RunSpec.


        :param ports: The ports of this V1RunSpec.  # noqa: E501
        :type ports: list[V1Port]
        """

        self._ports = ports

    @property
    def resource_spec(self):
        """Gets the resource_spec of this V1RunSpec.  # noqa: E501


        :return: The resource_spec of this V1RunSpec.  # noqa: E501
        :rtype: V1KernelResourceSpec
        """
        return self._resource_spec

    @resource_spec.setter
    def resource_spec(self, resource_spec):
        """Sets the resource_spec of this V1RunSpec.


        :param resource_spec: The resource_spec of this V1RunSpec.  # noqa: E501
        :type resource_spec: V1KernelResourceSpec
        """

        self._resource_spec = resource_spec

    @property
    def service_account_name(self):
        """Gets the service_account_name of this V1RunSpec.  # noqa: E501


        :return: The service_account_name of this V1RunSpec.  # noqa: E501
        :rtype: str
        """
        return self._service_account_name

    @service_account_name.setter
    def service_account_name(self, service_account_name):
        """Sets the service_account_name of this V1RunSpec.


        :param service_account_name: The service_account_name of this V1RunSpec.  # noqa: E501
        :type service_account_name: str
        """

        self._service_account_name = service_account_name

    @property
    def start_command(self):
        """Gets the start_command of this V1RunSpec.  # noqa: E501


        :return: The start_command of this V1RunSpec.  # noqa: E501
        :rtype: str
        """
        return self._start_command

    @start_command.setter
    def start_command(self, start_command):
        """Sets the start_command of this V1RunSpec.


        :param start_command: The start_command of this V1RunSpec.  # noqa: E501
        :type start_command: str
        """

        self._start_command = start_command

    @property
    def termination_protection(self):
        """Gets the termination_protection of this V1RunSpec.  # noqa: E501


        :return: The termination_protection of this V1RunSpec.  # noqa: E501
        :rtype: bool
        """
        return self._termination_protection

    @termination_protection.setter
    def termination_protection(self, termination_protection):
        """Sets the termination_protection of this V1RunSpec.


        :param termination_protection: The termination_protection of this V1RunSpec.  # noqa: E501
        :type termination_protection: bool
        """

        self._termination_protection = termination_protection

    @property
    def volume_claim_mounts(self):
        """Gets the volume_claim_mounts of this V1RunSpec.  # noqa: E501


        :return: The volume_claim_mounts of this V1RunSpec.  # noqa: E501
        :rtype: dict[str, V1VolumeClaimMount]
        """
        return self._volume_claim_mounts

    @volume_claim_mounts.setter
    def volume_claim_mounts(self, volume_claim_mounts):
        """Sets the volume_claim_mounts of this V1RunSpec.


        :param volume_claim_mounts: The volume_claim_mounts of this V1RunSpec.  # noqa: E501
        :type volume_claim_mounts: dict[str, V1VolumeClaimMount]
        """

        self._volume_claim_mounts = volume_claim_mounts

    @property
    def volume_v2_mounts(self):
        """Gets the volume_v2_mounts of this V1RunSpec.  # noqa: E501


        :return: The volume_v2_mounts of this V1RunSpec.  # noqa: E501
        :rtype: list[V1VolumeV2Mount]
        """
        return self._volume_v2_mounts

    @volume_v2_mounts.setter
    def volume_v2_mounts(self, volume_v2_mounts):
        """Sets the volume_v2_mounts of this V1RunSpec.


        :param volume_v2_mounts: The volume_v2_mounts of this V1RunSpec.  # noqa: E501
        :type volume_v2_mounts: list[V1VolumeV2Mount]
        """

        self._volume_v2_mounts = volume_v2_mounts

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1RunSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1RunSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from vessl.openapi_client.configuration import Configuration


class StorageCreateAPIInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cluster_id': 'int',
        'description': 'str',
        'name': 'str',
        'organization_credential_name': 'str',
        'read_only': 'bool',
        'storage_config': 'V1Config',
        'storage_type': 'str'
    }

    attribute_map = {
        'cluster_id': 'cluster_id',
        'description': 'description',
        'name': 'name',
        'organization_credential_name': 'organization_credential_name',
        'read_only': 'read_only',
        'storage_config': 'storage_config',
        'storage_type': 'storage_type'
    }

    def __init__(self, cluster_id=None, description=None, name=None, organization_credential_name=None, read_only=None, storage_config=None, storage_type=None, local_vars_configuration=None):  # noqa: E501
        """StorageCreateAPIInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._cluster_id = None
        self._description = None
        self._name = None
        self._organization_credential_name = None
        self._read_only = None
        self._storage_config = None
        self._storage_type = None
        self.discriminator = None

        self.cluster_id = cluster_id
        self.description = description
        self.name = name
        self.organization_credential_name = organization_credential_name
        self.read_only = read_only
        self.storage_config = storage_config
        if storage_type is not None:
            self.storage_type = storage_type

    @property
    def cluster_id(self):
        """Gets the cluster_id of this StorageCreateAPIInput.  # noqa: E501


        :return: The cluster_id of this StorageCreateAPIInput.  # noqa: E501
        :rtype: int
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        """Sets the cluster_id of this StorageCreateAPIInput.


        :param cluster_id: The cluster_id of this StorageCreateAPIInput.  # noqa: E501
        :type cluster_id: int
        """

        self._cluster_id = cluster_id

    @property
    def description(self):
        """Gets the description of this StorageCreateAPIInput.  # noqa: E501


        :return: The description of this StorageCreateAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this StorageCreateAPIInput.


        :param description: The description of this StorageCreateAPIInput.  # noqa: E501
        :type description: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 255):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `255`")  # noqa: E501

        self._description = description

    @property
    def name(self):
        """Gets the name of this StorageCreateAPIInput.  # noqa: E501


        :return: The name of this StorageCreateAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this StorageCreateAPIInput.


        :param name: The name of this StorageCreateAPIInput.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def organization_credential_name(self):
        """Gets the organization_credential_name of this StorageCreateAPIInput.  # noqa: E501


        :return: The organization_credential_name of this StorageCreateAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._organization_credential_name

    @organization_credential_name.setter
    def organization_credential_name(self, organization_credential_name):
        """Sets the organization_credential_name of this StorageCreateAPIInput.


        :param organization_credential_name: The organization_credential_name of this StorageCreateAPIInput.  # noqa: E501
        :type organization_credential_name: str
        """

        self._organization_credential_name = organization_credential_name

    @property
    def read_only(self):
        """Gets the read_only of this StorageCreateAPIInput.  # noqa: E501


        :return: The read_only of this StorageCreateAPIInput.  # noqa: E501
        :rtype: bool
        """
        return self._read_only

    @read_only.setter
    def read_only(self, read_only):
        """Sets the read_only of this StorageCreateAPIInput.


        :param read_only: The read_only of this StorageCreateAPIInput.  # noqa: E501
        :type read_only: bool
        """

        self._read_only = read_only

    @property
    def storage_config(self):
        """Gets the storage_config of this StorageCreateAPIInput.  # noqa: E501


        :return: The storage_config of this StorageCreateAPIInput.  # noqa: E501
        :rtype: V1Config
        """
        return self._storage_config

    @storage_config.setter
    def storage_config(self, storage_config):
        """Sets the storage_config of this StorageCreateAPIInput.


        :param storage_config: The storage_config of this StorageCreateAPIInput.  # noqa: E501
        :type storage_config: V1Config
        """
        if self.local_vars_configuration.client_side_validation and storage_config is None:  # noqa: E501
            raise ValueError("Invalid value for `storage_config`, must not be `None`")  # noqa: E501

        self._storage_config = storage_config

    @property
    def storage_type(self):
        """Gets the storage_type of this StorageCreateAPIInput.  # noqa: E501


        :return: The storage_type of this StorageCreateAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._storage_type

    @storage_type.setter
    def storage_type(self, storage_type):
        """Sets the storage_type of this StorageCreateAPIInput.


        :param storage_type: The storage_type of this StorageCreateAPIInput.  # noqa: E501
        :type storage_type: str
        """
        allowed_values = ["s3", "gcs", "cluster-nfs", "cluster-host-path"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and storage_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `storage_type` ({0}), must be one of {1}"  # noqa: E501
                .format(storage_type, allowed_values)
            )

        self._storage_type = storage_type

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StorageCreateAPIInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StorageCreateAPIInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from vessl.openapi_client.configuration import Configuration


class ResponseRunExecutionInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'arguments': 'V1RunArgument',
        'artifact_volume_info_list': 'list[ResponseRunExecutionArtifactVolume]',
        'create_dt': 'datetime',
        'created_by': 'ResponseUser',
        'endpoints': 'ResponseWorkloadEndpoints',
        'histories': 'list[ResponseWorkloadHistoryInfo]',
        'id': 'int',
        'immutable_slug': 'str',
        'interactive_end_dt': 'datetime',
        'is_starred': 'bool',
        'message': 'str',
        'metric_summary': 'V1LatestPlots',
        'organization': 'ResponseOrganization',
        'pipeline_step_execution': 'ResponseReducedPipelineStepExecution',
        'progress_percent': 'int',
        'project': 'ResponseProject',
        'run_spec': 'ResponseRunSpec',
        'status': 'str',
        'status_last_updated': 'datetime',
        'status_reason': 'str',
        'tags': 'list[ResponseTagResponse]',
        'volume_info_list': 'list[ResponseRunExecutionArtifactVolume]',
        'volume_operations': 'list[ResponsePathOperation]',
        'volume_v2_operations': 'list[ResponseWorkloadVolumeV2PathOperation]',
        'workload': 'ResponseWorkloadInfo'
    }

    attribute_map = {
        'arguments': 'arguments',
        'artifact_volume_info_list': 'artifact_volume_info_list',
        'create_dt': 'create_dt',
        'created_by': 'created_by',
        'endpoints': 'endpoints',
        'histories': 'histories',
        'id': 'id',
        'immutable_slug': 'immutable_slug',
        'interactive_end_dt': 'interactive_end_dt',
        'is_starred': 'is_starred',
        'message': 'message',
        'metric_summary': 'metric_summary',
        'organization': 'organization',
        'pipeline_step_execution': 'pipeline_step_execution',
        'progress_percent': 'progress_percent',
        'project': 'project',
        'run_spec': 'run_spec',
        'status': 'status',
        'status_last_updated': 'status_last_updated',
        'status_reason': 'status_reason',
        'tags': 'tags',
        'volume_info_list': 'volume_info_list',
        'volume_operations': 'volume_operations',
        'volume_v2_operations': 'volume_v2_operations',
        'workload': 'workload'
    }

    def __init__(self, arguments=None, artifact_volume_info_list=None, create_dt=None, created_by=None, endpoints=None, histories=None, id=None, immutable_slug=None, interactive_end_dt=None, is_starred=None, message=None, metric_summary=None, organization=None, pipeline_step_execution=None, progress_percent=None, project=None, run_spec=None, status=None, status_last_updated=None, status_reason=None, tags=None, volume_info_list=None, volume_operations=None, volume_v2_operations=None, workload=None, local_vars_configuration=None):  # noqa: E501
        """ResponseRunExecutionInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._arguments = None
        self._artifact_volume_info_list = None
        self._create_dt = None
        self._created_by = None
        self._endpoints = None
        self._histories = None
        self._id = None
        self._immutable_slug = None
        self._interactive_end_dt = None
        self._is_starred = None
        self._message = None
        self._metric_summary = None
        self._organization = None
        self._pipeline_step_execution = None
        self._progress_percent = None
        self._project = None
        self._run_spec = None
        self._status = None
        self._status_last_updated = None
        self._status_reason = None
        self._tags = None
        self._volume_info_list = None
        self._volume_operations = None
        self._volume_v2_operations = None
        self._workload = None
        self.discriminator = None

        if arguments is not None:
            self.arguments = arguments
        if artifact_volume_info_list is not None:
            self.artifact_volume_info_list = artifact_volume_info_list
        if create_dt is not None:
            self.create_dt = create_dt
        if created_by is not None:
            self.created_by = created_by
        if endpoints is not None:
            self.endpoints = endpoints
        self.histories = histories
        self.id = id
        self.immutable_slug = immutable_slug
        self.interactive_end_dt = interactive_end_dt
        self.is_starred = is_starred
        self.message = message
        if metric_summary is not None:
            self.metric_summary = metric_summary
        self.organization = organization
        if pipeline_step_execution is not None:
            self.pipeline_step_execution = pipeline_step_execution
        self.progress_percent = progress_percent
        if project is not None:
            self.project = project
        if run_spec is not None:
            self.run_spec = run_spec
        self.status = status
        if status_last_updated is not None:
            self.status_last_updated = status_last_updated
        self.status_reason = status_reason
        self.tags = tags
        if volume_info_list is not None:
            self.volume_info_list = volume_info_list
        if volume_operations is not None:
            self.volume_operations = volume_operations
        if volume_v2_operations is not None:
            self.volume_v2_operations = volume_v2_operations
        if workload is not None:
            self.workload = workload

    @property
    def arguments(self):
        """Gets the arguments of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The arguments of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: V1RunArgument
        """
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """Sets the arguments of this ResponseRunExecutionInfo.


        :param arguments: The arguments of this ResponseRunExecutionInfo.  # noqa: E501
        :type arguments: V1RunArgument
        """

        self._arguments = arguments

    @property
    def artifact_volume_info_list(self):
        """Gets the artifact_volume_info_list of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The artifact_volume_info_list of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: list[ResponseRunExecutionArtifactVolume]
        """
        return self._artifact_volume_info_list

    @artifact_volume_info_list.setter
    def artifact_volume_info_list(self, artifact_volume_info_list):
        """Sets the artifact_volume_info_list of this ResponseRunExecutionInfo.


        :param artifact_volume_info_list: The artifact_volume_info_list of this ResponseRunExecutionInfo.  # noqa: E501
        :type artifact_volume_info_list: list[ResponseRunExecutionArtifactVolume]
        """

        self._artifact_volume_info_list = artifact_volume_info_list

    @property
    def create_dt(self):
        """Gets the create_dt of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The create_dt of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._create_dt

    @create_dt.setter
    def create_dt(self, create_dt):
        """Sets the create_dt of this ResponseRunExecutionInfo.


        :param create_dt: The create_dt of this ResponseRunExecutionInfo.  # noqa: E501
        :type create_dt: datetime
        """

        self._create_dt = create_dt

    @property
    def created_by(self):
        """Gets the created_by of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The created_by of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: ResponseUser
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this ResponseRunExecutionInfo.


        :param created_by: The created_by of this ResponseRunExecutionInfo.  # noqa: E501
        :type created_by: ResponseUser
        """

        self._created_by = created_by

    @property
    def endpoints(self):
        """Gets the endpoints of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The endpoints of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: ResponseWorkloadEndpoints
        """
        return self._endpoints

    @endpoints.setter
    def endpoints(self, endpoints):
        """Sets the endpoints of this ResponseRunExecutionInfo.


        :param endpoints: The endpoints of this ResponseRunExecutionInfo.  # noqa: E501
        :type endpoints: ResponseWorkloadEndpoints
        """

        self._endpoints = endpoints

    @property
    def histories(self):
        """Gets the histories of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The histories of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: list[ResponseWorkloadHistoryInfo]
        """
        return self._histories

    @histories.setter
    def histories(self, histories):
        """Sets the histories of this ResponseRunExecutionInfo.


        :param histories: The histories of this ResponseRunExecutionInfo.  # noqa: E501
        :type histories: list[ResponseWorkloadHistoryInfo]
        """
        if self.local_vars_configuration.client_side_validation and histories is None:  # noqa: E501
            raise ValueError("Invalid value for `histories`, must not be `None`")  # noqa: E501

        self._histories = histories

    @property
    def id(self):
        """Gets the id of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The id of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ResponseRunExecutionInfo.


        :param id: The id of this ResponseRunExecutionInfo.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def immutable_slug(self):
        """Gets the immutable_slug of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The immutable_slug of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: str
        """
        return self._immutable_slug

    @immutable_slug.setter
    def immutable_slug(self, immutable_slug):
        """Sets the immutable_slug of this ResponseRunExecutionInfo.


        :param immutable_slug: The immutable_slug of this ResponseRunExecutionInfo.  # noqa: E501
        :type immutable_slug: str
        """
        if self.local_vars_configuration.client_side_validation and immutable_slug is None:  # noqa: E501
            raise ValueError("Invalid value for `immutable_slug`, must not be `None`")  # noqa: E501

        self._immutable_slug = immutable_slug

    @property
    def interactive_end_dt(self):
        """Gets the interactive_end_dt of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The interactive_end_dt of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._interactive_end_dt

    @interactive_end_dt.setter
    def interactive_end_dt(self, interactive_end_dt):
        """Sets the interactive_end_dt of this ResponseRunExecutionInfo.


        :param interactive_end_dt: The interactive_end_dt of this ResponseRunExecutionInfo.  # noqa: E501
        :type interactive_end_dt: datetime
        """

        self._interactive_end_dt = interactive_end_dt

    @property
    def is_starred(self):
        """Gets the is_starred of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The is_starred of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_starred

    @is_starred.setter
    def is_starred(self, is_starred):
        """Sets the is_starred of this ResponseRunExecutionInfo.


        :param is_starred: The is_starred of this ResponseRunExecutionInfo.  # noqa: E501
        :type is_starred: bool
        """
        if self.local_vars_configuration.client_side_validation and is_starred is None:  # noqa: E501
            raise ValueError("Invalid value for `is_starred`, must not be `None`")  # noqa: E501

        self._is_starred = is_starred

    @property
    def message(self):
        """Gets the message of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The message of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ResponseRunExecutionInfo.


        :param message: The message of this ResponseRunExecutionInfo.  # noqa: E501
        :type message: str
        """
        if self.local_vars_configuration.client_side_validation and message is None:  # noqa: E501
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    @property
    def metric_summary(self):
        """Gets the metric_summary of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The metric_summary of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: V1LatestPlots
        """
        return self._metric_summary

    @metric_summary.setter
    def metric_summary(self, metric_summary):
        """Sets the metric_summary of this ResponseRunExecutionInfo.


        :param metric_summary: The metric_summary of this ResponseRunExecutionInfo.  # noqa: E501
        :type metric_summary: V1LatestPlots
        """

        self._metric_summary = metric_summary

    @property
    def organization(self):
        """Gets the organization of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The organization of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: ResponseOrganization
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """Sets the organization of this ResponseRunExecutionInfo.


        :param organization: The organization of this ResponseRunExecutionInfo.  # noqa: E501
        :type organization: ResponseOrganization
        """
        if self.local_vars_configuration.client_side_validation and organization is None:  # noqa: E501
            raise ValueError("Invalid value for `organization`, must not be `None`")  # noqa: E501

        self._organization = organization

    @property
    def pipeline_step_execution(self):
        """Gets the pipeline_step_execution of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The pipeline_step_execution of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: ResponseReducedPipelineStepExecution
        """
        return self._pipeline_step_execution

    @pipeline_step_execution.setter
    def pipeline_step_execution(self, pipeline_step_execution):
        """Sets the pipeline_step_execution of this ResponseRunExecutionInfo.


        :param pipeline_step_execution: The pipeline_step_execution of this ResponseRunExecutionInfo.  # noqa: E501
        :type pipeline_step_execution: ResponseReducedPipelineStepExecution
        """

        self._pipeline_step_execution = pipeline_step_execution

    @property
    def progress_percent(self):
        """Gets the progress_percent of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The progress_percent of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: int
        """
        return self._progress_percent

    @progress_percent.setter
    def progress_percent(self, progress_percent):
        """Sets the progress_percent of this ResponseRunExecutionInfo.


        :param progress_percent: The progress_percent of this ResponseRunExecutionInfo.  # noqa: E501
        :type progress_percent: int
        """

        self._progress_percent = progress_percent

    @property
    def project(self):
        """Gets the project of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The project of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: ResponseProject
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this ResponseRunExecutionInfo.


        :param project: The project of this ResponseRunExecutionInfo.  # noqa: E501
        :type project: ResponseProject
        """

        self._project = project

    @property
    def run_spec(self):
        """Gets the run_spec of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The run_spec of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: ResponseRunSpec
        """
        return self._run_spec

    @run_spec.setter
    def run_spec(self, run_spec):
        """Sets the run_spec of this ResponseRunExecutionInfo.


        :param run_spec: The run_spec of this ResponseRunExecutionInfo.  # noqa: E501
        :type run_spec: ResponseRunSpec
        """

        self._run_spec = run_spec

    @property
    def status(self):
        """Gets the status of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The status of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ResponseRunExecutionInfo.


        :param status: The status of this ResponseRunExecutionInfo.  # noqa: E501
        :type status: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["queued", "pending", "running", "idle", "stopping", "failed", "completed", "terminated", "initializing", "waitToBeKilled"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def status_last_updated(self):
        """Gets the status_last_updated of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The status_last_updated of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._status_last_updated

    @status_last_updated.setter
    def status_last_updated(self, status_last_updated):
        """Sets the status_last_updated of this ResponseRunExecutionInfo.


        :param status_last_updated: The status_last_updated of this ResponseRunExecutionInfo.  # noqa: E501
        :type status_last_updated: datetime
        """

        self._status_last_updated = status_last_updated

    @property
    def status_reason(self):
        """Gets the status_reason of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The status_reason of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: str
        """
        return self._status_reason

    @status_reason.setter
    def status_reason(self, status_reason):
        """Sets the status_reason of this ResponseRunExecutionInfo.


        :param status_reason: The status_reason of this ResponseRunExecutionInfo.  # noqa: E501
        :type status_reason: str
        """
        if self.local_vars_configuration.client_side_validation and status_reason is None:  # noqa: E501
            raise ValueError("Invalid value for `status_reason`, must not be `None`")  # noqa: E501

        self._status_reason = status_reason

    @property
    def tags(self):
        """Gets the tags of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The tags of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: list[ResponseTagResponse]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this ResponseRunExecutionInfo.


        :param tags: The tags of this ResponseRunExecutionInfo.  # noqa: E501
        :type tags: list[ResponseTagResponse]
        """
        if self.local_vars_configuration.client_side_validation and tags is None:  # noqa: E501
            raise ValueError("Invalid value for `tags`, must not be `None`")  # noqa: E501

        self._tags = tags

    @property
    def volume_info_list(self):
        """Gets the volume_info_list of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The volume_info_list of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: list[ResponseRunExecutionArtifactVolume]
        """
        return self._volume_info_list

    @volume_info_list.setter
    def volume_info_list(self, volume_info_list):
        """Sets the volume_info_list of this ResponseRunExecutionInfo.


        :param volume_info_list: The volume_info_list of this ResponseRunExecutionInfo.  # noqa: E501
        :type volume_info_list: list[ResponseRunExecutionArtifactVolume]
        """

        self._volume_info_list = volume_info_list

    @property
    def volume_operations(self):
        """Gets the volume_operations of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The volume_operations of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: list[ResponsePathOperation]
        """
        return self._volume_operations

    @volume_operations.setter
    def volume_operations(self, volume_operations):
        """Sets the volume_operations of this ResponseRunExecutionInfo.


        :param volume_operations: The volume_operations of this ResponseRunExecutionInfo.  # noqa: E501
        :type volume_operations: list[ResponsePathOperation]
        """

        self._volume_operations = volume_operations

    @property
    def volume_v2_operations(self):
        """Gets the volume_v2_operations of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The volume_v2_operations of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: list[ResponseWorkloadVolumeV2PathOperation]
        """
        return self._volume_v2_operations

    @volume_v2_operations.setter
    def volume_v2_operations(self, volume_v2_operations):
        """Sets the volume_v2_operations of this ResponseRunExecutionInfo.


        :param volume_v2_operations: The volume_v2_operations of this ResponseRunExecutionInfo.  # noqa: E501
        :type volume_v2_operations: list[ResponseWorkloadVolumeV2PathOperation]
        """

        self._volume_v2_operations = volume_v2_operations

    @property
    def workload(self):
        """Gets the workload of this ResponseRunExecutionInfo.  # noqa: E501


        :return: The workload of this ResponseRunExecutionInfo.  # noqa: E501
        :rtype: ResponseWorkloadInfo
        """
        return self._workload

    @workload.setter
    def workload(self, workload):
        """Sets the workload of this ResponseRunExecutionInfo.


        :param workload: The workload of this ResponseRunExecutionInfo.  # noqa: E501
        :type workload: ResponseWorkloadInfo
        """

        self._workload = workload

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseRunExecutionInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponseRunExecutionInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from vessl.openapi_client.configuration import Configuration


class SamlRoleDescriptor(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cache_duration': 'str',
        'contact_people': 'list[SamlContactPerson]',
        'error_url': 'str',
        'id': 'str',
        'key_descriptors': 'list[SamlKeyDescriptor]',
        'organization': 'SamlOrganization',
        'protocol_support_enumeration': 'str',
        'signature': 'EtreeElement',
        'valid_until': 'datetime'
    }

    attribute_map = {
        'cache_duration': 'CacheDuration',
        'contact_people': 'ContactPeople',
        'error_url': 'ErrorURL',
        'id': 'ID',
        'key_descriptors': 'KeyDescriptors',
        'organization': 'Organization',
        'protocol_support_enumeration': 'ProtocolSupportEnumeration',
        'signature': 'Signature',
        'valid_until': 'ValidUntil'
    }

    def __init__(self, cache_duration=None, contact_people=None, error_url=None, id=None, key_descriptors=None, organization=None, protocol_support_enumeration=None, signature=None, valid_until=None, local_vars_configuration=None):  # noqa: E501
        """SamlRoleDescriptor - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._cache_duration = None
        self._contact_people = None
        self._error_url = None
        self._id = None
        self._key_descriptors = None
        self._organization = None
        self._protocol_support_enumeration = None
        self._signature = None
        self._valid_until = None
        self.discriminator = None

        if cache_duration is not None:
            self.cache_duration = cache_duration
        if contact_people is not None:
            self.contact_people = contact_people
        if error_url is not None:
            self.error_url = error_url
        if id is not None:
            self.id = id
        if key_descriptors is not None:
            self.key_descriptors = key_descriptors
        if organization is not None:
            self.organization = organization
        if protocol_support_enumeration is not None:
            self.protocol_support_enumeration = protocol_support_enumeration
        if signature is not None:
            self.signature = signature
        self.valid_until = valid_until

    @property
    def cache_duration(self):
        """Gets the cache_duration of this SamlRoleDescriptor.  # noqa: E501


        :return: The cache_duration of this SamlRoleDescriptor.  # noqa: E501
        :rtype: str
        """
        return self._cache_duration

    @cache_duration.setter
    def cache_duration(self, cache_duration):
        """Sets the cache_duration of this SamlRoleDescriptor.


        :param cache_duration: The cache_duration of this SamlRoleDescriptor.  # noqa: E501
        :type cache_duration: str
        """

        self._cache_duration = cache_duration

    @property
    def contact_people(self):
        """Gets the contact_people of this SamlRoleDescriptor.  # noqa: E501


        :return: The contact_people of this SamlRoleDescriptor.  # noqa: E501
        :rtype: list[SamlContactPerson]
        """
        return self._contact_people

    @contact_people.setter
    def contact_people(self, contact_people):
        """Sets the contact_people of this SamlRoleDescriptor.


        :param contact_people: The contact_people of this SamlRoleDescriptor.  # noqa: E501
        :type contact_people: list[SamlContactPerson]
        """

        self._contact_people = contact_people

    @property
    def error_url(self):
        """Gets the error_url of this SamlRoleDescriptor.  # noqa: E501


        :return: The error_url of this SamlRoleDescriptor.  # noqa: E501
        :rtype: str
        """
        return self._error_url

    @error_url.setter
    def error_url(self, error_url):
        """Sets the error_url of this SamlRoleDescriptor.


        :param error_url: The error_url of this SamlRoleDescriptor.  # noqa: E501
        :type error_url: str
        """

        self._error_url = error_url

    @property
    def id(self):
        """Gets the id of this SamlRoleDescriptor.  # noqa: E501


        :return: The id of this SamlRoleDescriptor.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SamlRoleDescriptor.


        :param id: The id of this SamlRoleDescriptor.  # noqa: E501
        :type id: str
        """

        self._id = id

    @property
    def key_descriptors(self):
        """Gets the key_descriptors of this SamlRoleDescriptor.  # noqa: E501


        :return: The key_descriptors of this SamlRoleDescriptor.  # noqa: E501
        :rtype: list[SamlKeyDescriptor]
        """
        return self._key_descriptors

    @key_descriptors.setter
    def key_descriptors(self, key_descriptors):
        """Sets the key_descriptors of this SamlRoleDescriptor.


        :param key_descriptors: The key_descriptors of this SamlRoleDescriptor.  # noqa: E501
        :type key_descriptors: list[SamlKeyDescriptor]
        """

        self._key_descriptors = key_descriptors

    @property
    def organization(self):
        """Gets the organization of this SamlRoleDescriptor.  # noqa: E501


        :return: The organization of this SamlRoleDescriptor.  # noqa: E501
        :rtype: SamlOrganization
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """Sets the organization of this SamlRoleDescriptor.


        :param organization: The organization of this SamlRoleDescriptor.  # noqa: E501
        :type organization: SamlOrganization
        """

        self._organization = organization

    @property
    def protocol_support_enumeration(self):
        """Gets the protocol_support_enumeration of this SamlRoleDescriptor.  # noqa: E501


        :return: The protocol_support_enumeration of this SamlRoleDescriptor.  # noqa: E501
        :rtype: str
        """
        return self._protocol_support_enumeration

    @protocol_support_enumeration.setter
    def protocol_support_enumeration(self, protocol_support_enumeration):
        """Sets the protocol_support_enumeration of this SamlRoleDescriptor.


        :param protocol_support_enumeration: The protocol_support_enumeration of this SamlRoleDescriptor.  # noqa: E501
        :type protocol_support_enumeration: str
        """

        self._protocol_support_enumeration = protocol_support_enumeration

    @property
    def signature(self):
        """Gets the signature of this SamlRoleDescriptor.  # noqa: E501


        :return: The signature of this SamlRoleDescriptor.  # noqa: E501
        :rtype: EtreeElement
        """
        return self._signature

    @signature.setter
    def signature(self, signature):
        """Sets the signature of this SamlRoleDescriptor.


        :param signature: The signature of this SamlRoleDescriptor.  # noqa: E501
        :type signature: EtreeElement
        """

        self._signature = signature

    @property
    def valid_until(self):
        """Gets the valid_until of this SamlRoleDescriptor.  # noqa: E501


        :return: The valid_until of this SamlRoleDescriptor.  # noqa: E501
        :rtype: datetime
        """
        return self._valid_until

    @valid_until.setter
    def valid_until(self, valid_until):
        """Sets the valid_until of this SamlRoleDescriptor.


        :param valid_until: The valid_until of this SamlRoleDescriptor.  # noqa: E501
        :type valid_until: datetime
        """

        self._valid_until = valid_until

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SamlRoleDescriptor):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SamlRoleDescriptor):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from vessl.openapi_client.configuration import Configuration


class ResponseModelServiceRevision(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'available_replicas': 'int',
        'created_by': 'ResponseUser',
        'created_dt': 'datetime',
        'id': 'int',
        'kernel_image': 'ResponseKernelImage',
        'kernel_resource_spec': 'ResponseKernelResourceSpec',
        'message': 'str',
        'model_service_name': 'str',
        'number': 'int',
        'resource_spec_name': 'str',
        'revision_spec': 'V1ModelServiceRevisionSpec',
        'service_account': 'V1ServiceAccount',
        'status': 'str',
        'total_replicas': 'int',
        'traffic_weight': 'int',
        'volume_operations': 'list[ResponsePathOperation]',
        'yaml_spec': 'str'
    }

    attribute_map = {
        'available_replicas': 'available_replicas',
        'created_by': 'created_by',
        'created_dt': 'created_dt',
        'id': 'id',
        'kernel_image': 'kernel_image',
        'kernel_resource_spec': 'kernel_resource_spec',
        'message': 'message',
        'model_service_name': 'model_service_name',
        'number': 'number',
        'resource_spec_name': 'resource_spec_name',
        'revision_spec': 'revision_spec',
        'service_account': 'service_account',
        'status': 'status',
        'total_replicas': 'total_replicas',
        'traffic_weight': 'traffic_weight',
        'volume_operations': 'volume_operations',
        'yaml_spec': 'yaml_spec'
    }

    def __init__(self, available_replicas=None, created_by=None, created_dt=None, id=None, kernel_image=None, kernel_resource_spec=None, message=None, model_service_name=None, number=None, resource_spec_name=None, revision_spec=None, service_account=None, status=None, total_replicas=None, traffic_weight=None, volume_operations=None, yaml_spec=None, local_vars_configuration=None):  # noqa: E501
        """ResponseModelServiceRevision - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._available_replicas = None
        self._created_by = None
        self._created_dt = None
        self._id = None
        self._kernel_image = None
        self._kernel_resource_spec = None
        self._message = None
        self._model_service_name = None
        self._number = None
        self._resource_spec_name = None
        self._revision_spec = None
        self._service_account = None
        self._status = None
        self._total_replicas = None
        self._traffic_weight = None
        self._volume_operations = None
        self._yaml_spec = None
        self.discriminator = None

        self.available_replicas = available_replicas
        self.created_by = created_by
        self.created_dt = created_dt
        self.id = id
        if kernel_image is not None:
            self.kernel_image = kernel_image
        if kernel_resource_spec is not None:
            self.kernel_resource_spec = kernel_resource_spec
        self.message = message
        self.model_service_name = model_service_name
        self.number = number
        self.resource_spec_name = resource_spec_name
        self.revision_spec = revision_spec
        if service_account is not None:
            self.service_account = service_account
        self.status = status
        self.total_replicas = total_replicas
        self.traffic_weight = traffic_weight
        if volume_operations is not None:
            self.volume_operations = volume_operations
        self.yaml_spec = yaml_spec

    @property
    def available_replicas(self):
        """Gets the available_replicas of this ResponseModelServiceRevision.  # noqa: E501


        :return: The available_replicas of this ResponseModelServiceRevision.  # noqa: E501
        :rtype: int
        """
        return self._available_replicas

    @available_replicas.setter
    def available_replicas(self, available_replicas):
        """Sets the available_replicas of this ResponseModelServiceRevision.


        :param available_replicas: The available_replicas of this ResponseModelServiceRevision.  # noqa: E501
        :type available_replicas: int
        """
        if self.local_vars_configuration.client_side_validation and available_replicas is None:  # noqa: E501
            raise ValueError("Invalid value for `available_replicas`, must not be `None`")  # noqa: E501

        self._available_replicas = available_replicas

    @property
    def created_by(self):
        """Gets the created_by of this ResponseModelServiceRevision.  # noqa: E501


        :return: The created_by of this ResponseModelServiceRevision.  # noqa: E501
        :rtype: ResponseUser
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this ResponseModelServiceRevision.


        :param created_by: The created_by of this ResponseModelServiceRevision.  # noqa: E501
        :type created_by: ResponseUser
        """
        if self.local_vars_configuration.client_side_validation and created_by is None:  # noqa: E501
            raise ValueError("Invalid value for `created_by`, must not be `None`")  # noqa: E501

        self._created_by = created_by

    @property
    def created_dt(self):
        """Gets the created_dt of this ResponseModelServiceRevision.  # noqa: E501


        :return: The created_dt of this ResponseModelServiceRevision.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this ResponseModelServiceRevision.


        :param created_dt: The created_dt of this ResponseModelServiceRevision.  # noqa: E501
        :type created_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `created_dt`, must not be `None`")  # noqa: E501

        self._created_dt = created_dt

    @property
    def id(self):
        """Gets the id of this ResponseModelServiceRevision.  # noqa: E501


        :return: The id of this ResponseModelServiceRevision.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ResponseModelServiceRevision.


        :param id: The id of this ResponseModelServiceRevision.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def kernel_image(self):
        """Gets the kernel_image of this ResponseModelServiceRevision.  # noqa: E501


        :return: The kernel_image of this ResponseModelServiceRevision.  # noqa: E501
        :rtype: ResponseKernelImage
        """
        return self._kernel_image

    @kernel_image.setter
    def kernel_image(self, kernel_image):
        """Sets the kernel_image of this ResponseModelServiceRevision.


        :param kernel_image: The kernel_image of this ResponseModelServiceRevision.  # noqa: E501
        :type kernel_image: ResponseKernelImage
        """

        self._kernel_image = kernel_image

    @property
    def kernel_resource_spec(self):
        """Gets the kernel_resource_spec of this ResponseModelServiceRevision.  # noqa: E501


        :return: The kernel_resource_spec of this ResponseModelServiceRevision.  # noqa: E501
        :rtype: ResponseKernelResourceSpec
        """
        return self._kernel_resource_spec

    @kernel_resource_spec.setter
    def kernel_resource_spec(self, kernel_resource_spec):
        """Sets the kernel_resource_spec of this ResponseModelServiceRevision.


        :param kernel_resource_spec: The kernel_resource_spec of this ResponseModelServiceRevision.  # noqa: E501
        :type kernel_resource_spec: ResponseKernelResourceSpec
        """

        self._kernel_resource_spec = kernel_resource_spec

    @property
    def message(self):
        """Gets the message of this ResponseModelServiceRevision.  # noqa: E501


        :return: The message of this ResponseModelServiceRevision.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ResponseModelServiceRevision.


        :param message: The message of this ResponseModelServiceRevision.  # noqa: E501
        :type message: str
        """
        if self.local_vars_configuration.client_side_validation and message is None:  # noqa: E501
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    @property
    def model_service_name(self):
        """Gets the model_service_name of this ResponseModelServiceRevision.  # noqa: E501


        :return: The model_service_name of this ResponseModelServiceRevision.  # noqa: E501
        :rtype: str
        """
        return self._model_service_name

    @model_service_name.setter
    def model_service_name(self, model_service_name):
        """Sets the model_service_name of this ResponseModelServiceRevision.


        :param model_service_name: The model_service_name of this ResponseModelServiceRevision.  # noqa: E501
        :type model_service_name: str
        """
        if self.local_vars_configuration.client_side_validation and model_service_name is None:  # noqa: E501
            raise ValueError("Invalid value for `model_service_name`, must not be `None`")  # noqa: E501

        self._model_service_name = model_service_name

    @property
    def number(self):
        """Gets the number of this ResponseModelServiceRevision.  # noqa: E501


        :return: The number of this ResponseModelServiceRevision.  # noqa: E501
        :rtype: int
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this ResponseModelServiceRevision.


        :param number: The number of this ResponseModelServiceRevision.  # noqa: E501
        :type number: int
        """
        if self.local_vars_configuration.client_side_validation and number is None:  # noqa: E501
            raise ValueError("Invalid value for `number`, must not be `None`")  # noqa: E501

        self._number = number

    @property
    def resource_spec_name(self):
        """Gets the resource_spec_name of this ResponseModelServiceRevision.  # noqa: E501


        :return: The resource_spec_name of this ResponseModelServiceRevision.  # noqa: E501
        :rtype: str
        """
        return self._resource_spec_name

    @resource_spec_name.setter
    def resource_spec_name(self, resource_spec_name):
        """Sets the resource_spec_name of this ResponseModelServiceRevision.


        :param resource_spec_name: The resource_spec_name of this ResponseModelServiceRevision.  # noqa: E501
        :type resource_spec_name: str
        """
        if self.local_vars_configuration.client_side_validation and resource_spec_name is None:  # noqa: E501
            raise ValueError("Invalid value for `resource_spec_name`, must not be `None`")  # noqa: E501

        self._resource_spec_name = resource_spec_name

    @property
    def revision_spec(self):
        """Gets the revision_spec of this ResponseModelServiceRevision.  # noqa: E501


        :return: The revision_spec of this ResponseModelServiceRevision.  # noqa: E501
        :rtype: V1ModelServiceRevisionSpec
        """
        return self._revision_spec

    @revision_spec.setter
    def revision_spec(self, revision_spec):
        """Sets the revision_spec of this ResponseModelServiceRevision.


        :param revision_spec: The revision_spec of this ResponseModelServiceRevision.  # noqa: E501
        :type revision_spec: V1ModelServiceRevisionSpec
        """
        if self.local_vars_configuration.client_side_validation and revision_spec is None:  # noqa: E501
            raise ValueError("Invalid value for `revision_spec`, must not be `None`")  # noqa: E501

        self._revision_spec = revision_spec

    @property
    def service_account(self):
        """Gets the service_account of this ResponseModelServiceRevision.  # noqa: E501


        :return: The service_account of this ResponseModelServiceRevision.  # noqa: E501
        :rtype: V1ServiceAccount
        """
        return self._service_account

    @service_account.setter
    def service_account(self, service_account):
        """Sets the service_account of this ResponseModelServiceRevision.


        :param service_account: The service_account of this ResponseModelServiceRevision.  # noqa: E501
        :type service_account: V1ServiceAccount
        """

        self._service_account = service_account

    @property
    def status(self):
        """Gets the status of this ResponseModelServiceRevision.  # noqa: E501


        :return: The status of this ResponseModelServiceRevision.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ResponseModelServiceRevision.


        :param status: The status of this ResponseModelServiceRevision.  # noqa: E501
        :type status: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def total_replicas(self):
        """Gets the total_replicas of this ResponseModelServiceRevision.  # noqa: E501


        :return: The total_replicas of this ResponseModelServiceRevision.  # noqa: E501
        :rtype: int
        """
        return self._total_replicas

    @total_replicas.setter
    def total_replicas(self, total_replicas):
        """Sets the total_replicas of this ResponseModelServiceRevision.


        :param total_replicas: The total_replicas of this ResponseModelServiceRevision.  # noqa: E501
        :type total_replicas: int
        """
        if self.local_vars_configuration.client_side_validation and total_replicas is None:  # noqa: E501
            raise ValueError("Invalid value for `total_replicas`, must not be `None`")  # noqa: E501

        self._total_replicas = total_replicas

    @property
    def traffic_weight(self):
        """Gets the traffic_weight of this ResponseModelServiceRevision.  # noqa: E501


        :return: The traffic_weight of this ResponseModelServiceRevision.  # noqa: E501
        :rtype: int
        """
        return self._traffic_weight

    @traffic_weight.setter
    def traffic_weight(self, traffic_weight):
        """Sets the traffic_weight of this ResponseModelServiceRevision.


        :param traffic_weight: The traffic_weight of this ResponseModelServiceRevision.  # noqa: E501
        :type traffic_weight: int
        """

        self._traffic_weight = traffic_weight

    @property
    def volume_operations(self):
        """Gets the volume_operations of this ResponseModelServiceRevision.  # noqa: E501


        :return: The volume_operations of this ResponseModelServiceRevision.  # noqa: E501
        :rtype: list[ResponsePathOperation]
        """
        return self._volume_operations

    @volume_operations.setter
    def volume_operations(self, volume_operations):
        """Sets the volume_operations of this ResponseModelServiceRevision.


        :param volume_operations: The volume_operations of this ResponseModelServiceRevision.  # noqa: E501
        :type volume_operations: list[ResponsePathOperation]
        """

        self._volume_operations = volume_operations

    @property
    def yaml_spec(self):
        """Gets the yaml_spec of this ResponseModelServiceRevision.  # noqa: E501


        :return: The yaml_spec of this ResponseModelServiceRevision.  # noqa: E501
        :rtype: str
        """
        return self._yaml_spec

    @yaml_spec.setter
    def yaml_spec(self, yaml_spec):
        """Sets the yaml_spec of this ResponseModelServiceRevision.


        :param yaml_spec: The yaml_spec of this ResponseModelServiceRevision.  # noqa: E501
        :type yaml_spec: str
        """

        self._yaml_spec = yaml_spec

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseModelServiceRevision):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponseModelServiceRevision):
            return True

        return self.to_dict() != other.to_dict()



from typing import Optional, Callable

from vessl.util.echo import print_warning


def deprecation_warning(target_command: str, new_command: Optional[str] = None):
    warning_text = f"The '{target_command}' command is deprecated and will be removed in a future release. "
    if new_command is not None:
        warning_text+=f"Please use the '{new_command}' command instead."
    print_warning(warning_text)


def deprecated(target_command: str, new_command: Optional[str] = None):
    def decorator(func: Callable):
        def wrapper(*args, **kwargs):
            deprecation_warning(target_command, new_command)
            return func(*args, **kwargs)
        return wrapper
    return decorator





from typing import List

from vessl.openapi_client.models.response_hub_model_task_list_response import (
    ResponseHubModelTaskListResponse,
)
from vessl.openapi_client.models.v1_hub_model_task_spec import V1HubModelTaskSpec
from vessl import __version__, vessl_api


def list_hub_model_tasks(
    tag: str = "",
    _type: str = "",
    limit: int = 50,
    offset: int = 0,
)-> List[V1HubModelTaskSpec]:
    tasks: ResponseHubModelTaskListResponse = vessl_api.hub_model_task_list_api(
        tag_match=tag,
        type_match=_type,
        limit=limit,
        offset=offset,
    )

    return tasks.results



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from vessl.openapi_client.configuration import Configuration


class V1HubModelTaskSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'category_id': 'int',
        'created_by': 'V1HubModelTaskSpecCreatedBy',
        'created_by_id': 'int',
        'description': 'str',
        'hide': 'bool',
        'hub_type': 'str',
        'id': 'int',
        'is_editable': 'bool',
        'key': 'str',
        'order_number': 'int',
        'overview': 'str',
        'public_url': 'str',
        'run_count': 'int',
        'scope': 'str',
        'status': 'str',
        'tags': 'list[V1HubTag]',
        'thumbnail_url': 'str',
        'title': 'str',
        'updated_dt': 'datetime',
        'version': 'int',
        'yaml': 'str'
    }

    attribute_map = {
        'category_id': 'category_id',
        'created_by': 'created_by',
        'created_by_id': 'created_by_id',
        'description': 'description',
        'hide': 'hide',
        'hub_type': 'hub_type',
        'id': 'id',
        'is_editable': 'is_editable',
        'key': 'key',
        'order_number': 'order_number',
        'overview': 'overview',
        'public_url': 'public_url',
        'run_count': 'run_count',
        'scope': 'scope',
        'status': 'status',
        'tags': 'tags',
        'thumbnail_url': 'thumbnail_url',
        'title': 'title',
        'updated_dt': 'updated_dt',
        'version': 'version',
        'yaml': 'yaml'
    }

    def __init__(self, category_id=None, created_by=None, created_by_id=None, description=None, hide=None, hub_type=None, id=None, is_editable=None, key=None, order_number=None, overview=None, public_url=None, run_count=None, scope=None, status=None, tags=None, thumbnail_url=None, title=None, updated_dt=None, version=None, yaml=None, local_vars_configuration=None):  # noqa: E501
        """V1HubModelTaskSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._category_id = None
        self._created_by = None
        self._created_by_id = None
        self._description = None
        self._hide = None
        self._hub_type = None
        self._id = None
        self._is_editable = None
        self._key = None
        self._order_number = None
        self._overview = None
        self._public_url = None
        self._run_count = None
        self._scope = None
        self._status = None
        self._tags = None
        self._thumbnail_url = None
        self._title = None
        self._updated_dt = None
        self._version = None
        self._yaml = None
        self.discriminator = None

        self.category_id = category_id
        if created_by is not None:
            self.created_by = created_by
        if created_by_id is not None:
            self.created_by_id = created_by_id
        if description is not None:
            self.description = description
        self.hide = hide
        self.hub_type = hub_type
        self.id = id
        self.is_editable = is_editable
        self.key = key
        self.order_number = order_number
        self.overview = overview
        if public_url is not None:
            self.public_url = public_url
        self.run_count = run_count
        self.scope = scope
        self.status = status
        if tags is not None:
            self.tags = tags
        if thumbnail_url is not None:
            self.thumbnail_url = thumbnail_url
        self.title = title
        self.updated_dt = updated_dt
        self.version = version
        self.yaml = yaml

    @property
    def category_id(self):
        """Gets the category_id of this V1HubModelTaskSpec.  # noqa: E501


        :return: The category_id of this V1HubModelTaskSpec.  # noqa: E501
        :rtype: int
        """
        return self._category_id

    @category_id.setter
    def category_id(self, category_id):
        """Sets the category_id of this V1HubModelTaskSpec.


        :param category_id: The category_id of this V1HubModelTaskSpec.  # noqa: E501
        :type category_id: int
        """

        self._category_id = category_id

    @property
    def created_by(self):
        """Gets the created_by of this V1HubModelTaskSpec.  # noqa: E501


        :return: The created_by of this V1HubModelTaskSpec.  # noqa: E501
        :rtype: V1HubModelTaskSpecCreatedBy
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this V1HubModelTaskSpec.


        :param created_by: The created_by of this V1HubModelTaskSpec.  # noqa: E501
        :type created_by: V1HubModelTaskSpecCreatedBy
        """

        self._created_by = created_by

    @property
    def created_by_id(self):
        """Gets the created_by_id of this V1HubModelTaskSpec.  # noqa: E501


        :return: The created_by_id of this V1HubModelTaskSpec.  # noqa: E501
        :rtype: int
        """
        return self._created_by_id

    @created_by_id.setter
    def created_by_id(self, created_by_id):
        """Sets the created_by_id of this V1HubModelTaskSpec.


        :param created_by_id: The created_by_id of this V1HubModelTaskSpec.  # noqa: E501
        :type created_by_id: int
        """

        self._created_by_id = created_by_id

    @property
    def description(self):
        """Gets the description of this V1HubModelTaskSpec.  # noqa: E501


        :return: The description of this V1HubModelTaskSpec.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this V1HubModelTaskSpec.


        :param description: The description of this V1HubModelTaskSpec.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def hide(self):
        """Gets the hide of this V1HubModelTaskSpec.  # noqa: E501


        :return: The hide of this V1HubModelTaskSpec.  # noqa: E501
        :rtype: bool
        """
        return self._hide

    @hide.setter
    def hide(self, hide):
        """Sets the hide of this V1HubModelTaskSpec.


        :param hide: The hide of this V1HubModelTaskSpec.  # noqa: E501
        :type hide: bool
        """
        if self.local_vars_configuration.client_side_validation and hide is None:  # noqa: E501
            raise ValueError("Invalid value for `hide`, must not be `None`")  # noqa: E501

        self._hide = hide

    @property
    def hub_type(self):
        """Gets the hub_type of this V1HubModelTaskSpec.  # noqa: E501


        :return: The hub_type of this V1HubModelTaskSpec.  # noqa: E501
        :rtype: str
        """
        return self._hub_type

    @hub_type.setter
    def hub_type(self, hub_type):
        """Sets the hub_type of this V1HubModelTaskSpec.


        :param hub_type: The hub_type of this V1HubModelTaskSpec.  # noqa: E501
        :type hub_type: str
        """
        if self.local_vars_configuration.client_side_validation and hub_type is None:  # noqa: E501
            raise ValueError("Invalid value for `hub_type`, must not be `None`")  # noqa: E501

        self._hub_type = hub_type

    @property
    def id(self):
        """Gets the id of this V1HubModelTaskSpec.  # noqa: E501


        :return: The id of this V1HubModelTaskSpec.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this V1HubModelTaskSpec.


        :param id: The id of this V1HubModelTaskSpec.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def is_editable(self):
        """Gets the is_editable of this V1HubModelTaskSpec.  # noqa: E501


        :return: The is_editable of this V1HubModelTaskSpec.  # noqa: E501
        :rtype: bool
        """
        return self._is_editable

    @is_editable.setter
    def is_editable(self, is_editable):
        """Sets the is_editable of this V1HubModelTaskSpec.


        :param is_editable: The is_editable of this V1HubModelTaskSpec.  # noqa: E501
        :type is_editable: bool
        """
        if self.local_vars_configuration.client_side_validation and is_editable is None:  # noqa: E501
            raise ValueError("Invalid value for `is_editable`, must not be `None`")  # noqa: E501

        self._is_editable = is_editable

    @property
    def key(self):
        """Gets the key of this V1HubModelTaskSpec.  # noqa: E501


        :return: The key of this V1HubModelTaskSpec.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this V1HubModelTaskSpec.


        :param key: The key of this V1HubModelTaskSpec.  # noqa: E501
        :type key: str
        """
        if self.local_vars_configuration.client_side_validation and key is None:  # noqa: E501
            raise ValueError("Invalid value for `key`, must not be `None`")  # noqa: E501

        self._key = key

    @property
    def order_number(self):
        """Gets the order_number of this V1HubModelTaskSpec.  # noqa: E501


        :return: The order_number of this V1HubModelTaskSpec.  # noqa: E501
        :rtype: int
        """
        return self._order_number

    @order_number.setter
    def order_number(self, order_number):
        """Sets the order_number of this V1HubModelTaskSpec.


        :param order_number: The order_number of this V1HubModelTaskSpec.  # noqa: E501
        :type order_number: int
        """
        if self.local_vars_configuration.client_side_validation and order_number is None:  # noqa: E501
            raise ValueError("Invalid value for `order_number`, must not be `None`")  # noqa: E501

        self._order_number = order_number

    @property
    def overview(self):
        """Gets the overview of this V1HubModelTaskSpec.  # noqa: E501


        :return: The overview of this V1HubModelTaskSpec.  # noqa: E501
        :rtype: str
        """
        return self._overview

    @overview.setter
    def overview(self, overview):
        """Sets the overview of this V1HubModelTaskSpec.


        :param overview: The overview of this V1HubModelTaskSpec.  # noqa: E501
        :type overview: str
        """
        if self.local_vars_configuration.client_side_validation and overview is None:  # noqa: E501
            raise ValueError("Invalid value for `overview`, must not be `None`")  # noqa: E501

        self._overview = overview

    @property
    def public_url(self):
        """Gets the public_url of this V1HubModelTaskSpec.  # noqa: E501


        :return: The public_url of this V1HubModelTaskSpec.  # noqa: E501
        :rtype: str
        """
        return self._public_url

    @public_url.setter
    def public_url(self, public_url):
        """Sets the public_url of this V1HubModelTaskSpec.


        :param public_url: The public_url of this V1HubModelTaskSpec.  # noqa: E501
        :type public_url: str
        """

        self._public_url = public_url

    @property
    def run_count(self):
        """Gets the run_count of this V1HubModelTaskSpec.  # noqa: E501


        :return: The run_count of this V1HubModelTaskSpec.  # noqa: E501
        :rtype: int
        """
        return self._run_count

    @run_count.setter
    def run_count(self, run_count):
        """Sets the run_count of this V1HubModelTaskSpec.


        :param run_count: The run_count of this V1HubModelTaskSpec.  # noqa: E501
        :type run_count: int
        """
        if self.local_vars_configuration.client_side_validation and run_count is None:  # noqa: E501
            raise ValueError("Invalid value for `run_count`, must not be `None`")  # noqa: E501

        self._run_count = run_count

    @property
    def scope(self):
        """Gets the scope of this V1HubModelTaskSpec.  # noqa: E501


        :return: The scope of this V1HubModelTaskSpec.  # noqa: E501
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this V1HubModelTaskSpec.


        :param scope: The scope of this V1HubModelTaskSpec.  # noqa: E501
        :type scope: str
        """
        if self.local_vars_configuration.client_side_validation and scope is None:  # noqa: E501
            raise ValueError("Invalid value for `scope`, must not be `None`")  # noqa: E501

        self._scope = scope

    @property
    def status(self):
        """Gets the status of this V1HubModelTaskSpec.  # noqa: E501


        :return: The status of this V1HubModelTaskSpec.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this V1HubModelTaskSpec.


        :param status: The status of this V1HubModelTaskSpec.  # noqa: E501
        :type status: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def tags(self):
        """Gets the tags of this V1HubModelTaskSpec.  # noqa: E501


        :return: The tags of this V1HubModelTaskSpec.  # noqa: E501
        :rtype: list[V1HubTag]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this V1HubModelTaskSpec.


        :param tags: The tags of this V1HubModelTaskSpec.  # noqa: E501
        :type tags: list[V1HubTag]
        """

        self._tags = tags

    @property
    def thumbnail_url(self):
        """Gets the thumbnail_url of this V1HubModelTaskSpec.  # noqa: E501


        :return: The thumbnail_url of this V1HubModelTaskSpec.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail_url

    @thumbnail_url.setter
    def thumbnail_url(self, thumbnail_url):
        """Sets the thumbnail_url of this V1HubModelTaskSpec.


        :param thumbnail_url: The thumbnail_url of this V1HubModelTaskSpec.  # noqa: E501
        :type thumbnail_url: str
        """

        self._thumbnail_url = thumbnail_url

    @property
    def title(self):
        """Gets the title of this V1HubModelTaskSpec.  # noqa: E501


        :return: The title of this V1HubModelTaskSpec.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this V1HubModelTaskSpec.


        :param title: The title of this V1HubModelTaskSpec.  # noqa: E501
        :type title: str
        """
        if self.local_vars_configuration.client_side_validation and title is None:  # noqa: E501
            raise ValueError("Invalid value for `title`, must not be `None`")  # noqa: E501

        self._title = title

    @property
    def updated_dt(self):
        """Gets the updated_dt of this V1HubModelTaskSpec.  # noqa: E501


        :return: The updated_dt of this V1HubModelTaskSpec.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this V1HubModelTaskSpec.


        :param updated_dt: The updated_dt of this V1HubModelTaskSpec.  # noqa: E501
        :type updated_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_dt`, must not be `None`")  # noqa: E501

        self._updated_dt = updated_dt

    @property
    def version(self):
        """Gets the version of this V1HubModelTaskSpec.  # noqa: E501


        :return: The version of this V1HubModelTaskSpec.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this V1HubModelTaskSpec.


        :param version: The version of this V1HubModelTaskSpec.  # noqa: E501
        :type version: int
        """

        self._version = version

    @property
    def yaml(self):
        """Gets the yaml of this V1HubModelTaskSpec.  # noqa: E501


        :return: The yaml of this V1HubModelTaskSpec.  # noqa: E501
        :rtype: str
        """
        return self._yaml

    @yaml.setter
    def yaml(self, yaml):
        """Sets the yaml of this V1HubModelTaskSpec.


        :param yaml: The yaml of this V1HubModelTaskSpec.  # noqa: E501
        :type yaml: str
        """
        if self.local_vars_configuration.client_side_validation and yaml is None:  # noqa: E501
            raise ValueError("Invalid value for `yaml`, must not be `None`")  # noqa: E501

        self._yaml = yaml

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1HubModelTaskSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1HubModelTaskSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from vessl.openapi_client.configuration import Configuration


class OrmExperimentFilterValues(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'bool_value': 'bool',
        'datetime_value': 'float',
        'duration_value': 'OrmDurationValue',
        'enum_values': 'list[str]',
        'number_values': 'list[float]',
        'object_values': 'list[int]',
        'string_values': 'list[str]',
        'tag_values': 'list[int]'
    }

    attribute_map = {
        'bool_value': 'bool_value',
        'datetime_value': 'datetime_value',
        'duration_value': 'duration_value',
        'enum_values': 'enum_values',
        'number_values': 'number_values',
        'object_values': 'object_values',
        'string_values': 'string_values',
        'tag_values': 'tag_values'
    }

    def __init__(self, bool_value=None, datetime_value=None, duration_value=None, enum_values=None, number_values=None, object_values=None, string_values=None, tag_values=None, local_vars_configuration=None):  # noqa: E501
        """OrmExperimentFilterValues - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._bool_value = None
        self._datetime_value = None
        self._duration_value = None
        self._enum_values = None
        self._number_values = None
        self._object_values = None
        self._string_values = None
        self._tag_values = None
        self.discriminator = None

        self.bool_value = bool_value
        self.datetime_value = datetime_value
        if duration_value is not None:
            self.duration_value = duration_value
        if enum_values is not None:
            self.enum_values = enum_values
        if number_values is not None:
            self.number_values = number_values
        if object_values is not None:
            self.object_values = object_values
        if string_values is not None:
            self.string_values = string_values
        if tag_values is not None:
            self.tag_values = tag_values

    @property
    def bool_value(self):
        """Gets the bool_value of this OrmExperimentFilterValues.  # noqa: E501


        :return: The bool_value of this OrmExperimentFilterValues.  # noqa: E501
        :rtype: bool
        """
        return self._bool_value

    @bool_value.setter
    def bool_value(self, bool_value):
        """Sets the bool_value of this OrmExperimentFilterValues.


        :param bool_value: The bool_value of this OrmExperimentFilterValues.  # noqa: E501
        :type bool_value: bool
        """

        self._bool_value = bool_value

    @property
    def datetime_value(self):
        """Gets the datetime_value of this OrmExperimentFilterValues.  # noqa: E501


        :return: The datetime_value of this OrmExperimentFilterValues.  # noqa: E501
        :rtype: float
        """
        return self._datetime_value

    @datetime_value.setter
    def datetime_value(self, datetime_value):
        """Sets the datetime_value of this OrmExperimentFilterValues.


        :param datetime_value: The datetime_value of this OrmExperimentFilterValues.  # noqa: E501
        :type datetime_value: float
        """

        self._datetime_value = datetime_value

    @property
    def duration_value(self):
        """Gets the duration_value of this OrmExperimentFilterValues.  # noqa: E501


        :return: The duration_value of this OrmExperimentFilterValues.  # noqa: E501
        :rtype: OrmDurationValue
        """
        return self._duration_value

    @duration_value.setter
    def duration_value(self, duration_value):
        """Sets the duration_value of this OrmExperimentFilterValues.


        :param duration_value: The duration_value of this OrmExperimentFilterValues.  # noqa: E501
        :type duration_value: OrmDurationValue
        """

        self._duration_value = duration_value

    @property
    def enum_values(self):
        """Gets the enum_values of this OrmExperimentFilterValues.  # noqa: E501


        :return: The enum_values of this OrmExperimentFilterValues.  # noqa: E501
        :rtype: list[str]
        """
        return self._enum_values

    @enum_values.setter
    def enum_values(self, enum_values):
        """Sets the enum_values of this OrmExperimentFilterValues.


        :param enum_values: The enum_values of this OrmExperimentFilterValues.  # noqa: E501
        :type enum_values: list[str]
        """

        self._enum_values = enum_values

    @property
    def number_values(self):
        """Gets the number_values of this OrmExperimentFilterValues.  # noqa: E501


        :return: The number_values of this OrmExperimentFilterValues.  # noqa: E501
        :rtype: list[float]
        """
        return self._number_values

    @number_values.setter
    def number_values(self, number_values):
        """Sets the number_values of this OrmExperimentFilterValues.


        :param number_values: The number_values of this OrmExperimentFilterValues.  # noqa: E501
        :type number_values: list[float]
        """

        self._number_values = number_values

    @property
    def object_values(self):
        """Gets the object_values of this OrmExperimentFilterValues.  # noqa: E501


        :return: The object_values of this OrmExperimentFilterValues.  # noqa: E501
        :rtype: list[int]
        """
        return self._object_values

    @object_values.setter
    def object_values(self, object_values):
        """Sets the object_values of this OrmExperimentFilterValues.


        :param object_values: The object_values of this OrmExperimentFilterValues.  # noqa: E501
        :type object_values: list[int]
        """

        self._object_values = object_values

    @property
    def string_values(self):
        """Gets the string_values of this OrmExperimentFilterValues.  # noqa: E501


        :return: The string_values of this OrmExperimentFilterValues.  # noqa: E501
        :rtype: list[str]
        """
        return self._string_values

    @string_values.setter
    def string_values(self, string_values):
        """Sets the string_values of this OrmExperimentFilterValues.


        :param string_values: The string_values of this OrmExperimentFilterValues.  # noqa: E501
        :type string_values: list[str]
        """

        self._string_values = string_values

    @property
    def tag_values(self):
        """Gets the tag_values of this OrmExperimentFilterValues.  # noqa: E501


        :return: The tag_values of this OrmExperimentFilterValues.  # noqa: E501
        :rtype: list[int]
        """
        return self._tag_values

    @tag_values.setter
    def tag_values(self, tag_values):
        """Sets the tag_values of this OrmExperimentFilterValues.


        :param tag_values: The tag_values of this OrmExperimentFilterValues.  # noqa: E501
        :type tag_values: list[int]
        """

        self._tag_values = tag_values

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmExperimentFilterValues):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmExperimentFilterValues):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from vessl.openapi_client.configuration import Configuration


class ClientconfigFrontendConfigResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'billing_credit_enabled': 'bool',
        'cluster_create_enabled': 'bool',
        'google_client_id': 'str',
        'google_recaptcha_site_key': 'str',
        'model_enabled': 'bool',
        'notification_settings_enabled': 'bool',
        'root_directory_volume_mount_enabled': 'bool',
        'serverless_service_enabled': 'bool',
        'signup_enabled': 'bool',
        'user_cluster_ops_enabled': 'bool',
        'user_phone_number_enabled': 'bool',
        'user_volume_ops_enabled': 'bool',
        'vessl_storage_enabled': 'bool'
    }

    attribute_map = {
        'billing_credit_enabled': 'billing_credit_enabled',
        'cluster_create_enabled': 'cluster_create_enabled',
        'google_client_id': 'google_client_id',
        'google_recaptcha_site_key': 'google_recaptcha_site_key',
        'model_enabled': 'model_enabled',
        'notification_settings_enabled': 'notification_settings_enabled',
        'root_directory_volume_mount_enabled': 'root_directory_volume_mount_enabled',
        'serverless_service_enabled': 'serverless_service_enabled',
        'signup_enabled': 'signup_enabled',
        'user_cluster_ops_enabled': 'user_cluster_ops_enabled',
        'user_phone_number_enabled': 'user_phone_number_enabled',
        'user_volume_ops_enabled': 'user_volume_ops_enabled',
        'vessl_storage_enabled': 'vessl_storage_enabled'
    }

    def __init__(self, billing_credit_enabled=None, cluster_create_enabled=None, google_client_id=None, google_recaptcha_site_key=None, model_enabled=None, notification_settings_enabled=None, root_directory_volume_mount_enabled=None, serverless_service_enabled=None, signup_enabled=None, user_cluster_ops_enabled=None, user_phone_number_enabled=None, user_volume_ops_enabled=None, vessl_storage_enabled=None, local_vars_configuration=None):  # noqa: E501
        """ClientconfigFrontendConfigResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._billing_credit_enabled = None
        self._cluster_create_enabled = None
        self._google_client_id = None
        self._google_recaptcha_site_key = None
        self._model_enabled = None
        self._notification_settings_enabled = None
        self._root_directory_volume_mount_enabled = None
        self._serverless_service_enabled = None
        self._signup_enabled = None
        self._user_cluster_ops_enabled = None
        self._user_phone_number_enabled = None
        self._user_volume_ops_enabled = None
        self._vessl_storage_enabled = None
        self.discriminator = None

        self.billing_credit_enabled = billing_credit_enabled
        self.cluster_create_enabled = cluster_create_enabled
        self.google_client_id = google_client_id
        self.google_recaptcha_site_key = google_recaptcha_site_key
        self.model_enabled = model_enabled
        self.notification_settings_enabled = notification_settings_enabled
        self.root_directory_volume_mount_enabled = root_directory_volume_mount_enabled
        self.serverless_service_enabled = serverless_service_enabled
        self.signup_enabled = signup_enabled
        if user_cluster_ops_enabled is not None:
            self.user_cluster_ops_enabled = user_cluster_ops_enabled
        self.user_phone_number_enabled = user_phone_number_enabled
        if user_volume_ops_enabled is not None:
            self.user_volume_ops_enabled = user_volume_ops_enabled
        self.vessl_storage_enabled = vessl_storage_enabled

    @property
    def billing_credit_enabled(self):
        """Gets the billing_credit_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501


        :return: The billing_credit_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :rtype: bool
        """
        return self._billing_credit_enabled

    @billing_credit_enabled.setter
    def billing_credit_enabled(self, billing_credit_enabled):
        """Sets the billing_credit_enabled of this ClientconfigFrontendConfigResponse.


        :param billing_credit_enabled: The billing_credit_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :type billing_credit_enabled: bool
        """
        if self.local_vars_configuration.client_side_validation and billing_credit_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `billing_credit_enabled`, must not be `None`")  # noqa: E501

        self._billing_credit_enabled = billing_credit_enabled

    @property
    def cluster_create_enabled(self):
        """Gets the cluster_create_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501


        :return: The cluster_create_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :rtype: bool
        """
        return self._cluster_create_enabled

    @cluster_create_enabled.setter
    def cluster_create_enabled(self, cluster_create_enabled):
        """Sets the cluster_create_enabled of this ClientconfigFrontendConfigResponse.


        :param cluster_create_enabled: The cluster_create_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :type cluster_create_enabled: bool
        """
        if self.local_vars_configuration.client_side_validation and cluster_create_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `cluster_create_enabled`, must not be `None`")  # noqa: E501

        self._cluster_create_enabled = cluster_create_enabled

    @property
    def google_client_id(self):
        """Gets the google_client_id of this ClientconfigFrontendConfigResponse.  # noqa: E501


        :return: The google_client_id of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :rtype: str
        """
        return self._google_client_id

    @google_client_id.setter
    def google_client_id(self, google_client_id):
        """Sets the google_client_id of this ClientconfigFrontendConfigResponse.


        :param google_client_id: The google_client_id of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :type google_client_id: str
        """
        if self.local_vars_configuration.client_side_validation and google_client_id is None:  # noqa: E501
            raise ValueError("Invalid value for `google_client_id`, must not be `None`")  # noqa: E501

        self._google_client_id = google_client_id

    @property
    def google_recaptcha_site_key(self):
        """Gets the google_recaptcha_site_key of this ClientconfigFrontendConfigResponse.  # noqa: E501


        :return: The google_recaptcha_site_key of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :rtype: str
        """
        return self._google_recaptcha_site_key

    @google_recaptcha_site_key.setter
    def google_recaptcha_site_key(self, google_recaptcha_site_key):
        """Sets the google_recaptcha_site_key of this ClientconfigFrontendConfigResponse.


        :param google_recaptcha_site_key: The google_recaptcha_site_key of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :type google_recaptcha_site_key: str
        """
        if self.local_vars_configuration.client_side_validation and google_recaptcha_site_key is None:  # noqa: E501
            raise ValueError("Invalid value for `google_recaptcha_site_key`, must not be `None`")  # noqa: E501

        self._google_recaptcha_site_key = google_recaptcha_site_key

    @property
    def model_enabled(self):
        """Gets the model_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501


        :return: The model_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :rtype: bool
        """
        return self._model_enabled

    @model_enabled.setter
    def model_enabled(self, model_enabled):
        """Sets the model_enabled of this ClientconfigFrontendConfigResponse.


        :param model_enabled: The model_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :type model_enabled: bool
        """
        if self.local_vars_configuration.client_side_validation and model_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `model_enabled`, must not be `None`")  # noqa: E501

        self._model_enabled = model_enabled

    @property
    def notification_settings_enabled(self):
        """Gets the notification_settings_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501


        :return: The notification_settings_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :rtype: bool
        """
        return self._notification_settings_enabled

    @notification_settings_enabled.setter
    def notification_settings_enabled(self, notification_settings_enabled):
        """Sets the notification_settings_enabled of this ClientconfigFrontendConfigResponse.


        :param notification_settings_enabled: The notification_settings_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :type notification_settings_enabled: bool
        """
        if self.local_vars_configuration.client_side_validation and notification_settings_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `notification_settings_enabled`, must not be `None`")  # noqa: E501

        self._notification_settings_enabled = notification_settings_enabled

    @property
    def root_directory_volume_mount_enabled(self):
        """Gets the root_directory_volume_mount_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501


        :return: The root_directory_volume_mount_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :rtype: bool
        """
        return self._root_directory_volume_mount_enabled

    @root_directory_volume_mount_enabled.setter
    def root_directory_volume_mount_enabled(self, root_directory_volume_mount_enabled):
        """Sets the root_directory_volume_mount_enabled of this ClientconfigFrontendConfigResponse.


        :param root_directory_volume_mount_enabled: The root_directory_volume_mount_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :type root_directory_volume_mount_enabled: bool
        """
        if self.local_vars_configuration.client_side_validation and root_directory_volume_mount_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `root_directory_volume_mount_enabled`, must not be `None`")  # noqa: E501

        self._root_directory_volume_mount_enabled = root_directory_volume_mount_enabled

    @property
    def serverless_service_enabled(self):
        """Gets the serverless_service_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501


        :return: The serverless_service_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :rtype: bool
        """
        return self._serverless_service_enabled

    @serverless_service_enabled.setter
    def serverless_service_enabled(self, serverless_service_enabled):
        """Sets the serverless_service_enabled of this ClientconfigFrontendConfigResponse.


        :param serverless_service_enabled: The serverless_service_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :type serverless_service_enabled: bool
        """
        if self.local_vars_configuration.client_side_validation and serverless_service_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `serverless_service_enabled`, must not be `None`")  # noqa: E501

        self._serverless_service_enabled = serverless_service_enabled

    @property
    def signup_enabled(self):
        """Gets the signup_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501


        :return: The signup_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :rtype: bool
        """
        return self._signup_enabled

    @signup_enabled.setter
    def signup_enabled(self, signup_enabled):
        """Sets the signup_enabled of this ClientconfigFrontendConfigResponse.


        :param signup_enabled: The signup_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :type signup_enabled: bool
        """
        if self.local_vars_configuration.client_side_validation and signup_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `signup_enabled`, must not be `None`")  # noqa: E501

        self._signup_enabled = signup_enabled

    @property
    def user_cluster_ops_enabled(self):
        """Gets the user_cluster_ops_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501


        :return: The user_cluster_ops_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :rtype: bool
        """
        return self._user_cluster_ops_enabled

    @user_cluster_ops_enabled.setter
    def user_cluster_ops_enabled(self, user_cluster_ops_enabled):
        """Sets the user_cluster_ops_enabled of this ClientconfigFrontendConfigResponse.


        :param user_cluster_ops_enabled: The user_cluster_ops_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :type user_cluster_ops_enabled: bool
        """

        self._user_cluster_ops_enabled = user_cluster_ops_enabled

    @property
    def user_phone_number_enabled(self):
        """Gets the user_phone_number_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501


        :return: The user_phone_number_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :rtype: bool
        """
        return self._user_phone_number_enabled

    @user_phone_number_enabled.setter
    def user_phone_number_enabled(self, user_phone_number_enabled):
        """Sets the user_phone_number_enabled of this ClientconfigFrontendConfigResponse.


        :param user_phone_number_enabled: The user_phone_number_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :type user_phone_number_enabled: bool
        """
        if self.local_vars_configuration.client_side_validation and user_phone_number_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `user_phone_number_enabled`, must not be `None`")  # noqa: E501

        self._user_phone_number_enabled = user_phone_number_enabled

    @property
    def user_volume_ops_enabled(self):
        """Gets the user_volume_ops_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501


        :return: The user_volume_ops_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :rtype: bool
        """
        return self._user_volume_ops_enabled

    @user_volume_ops_enabled.setter
    def user_volume_ops_enabled(self, user_volume_ops_enabled):
        """Sets the user_volume_ops_enabled of this ClientconfigFrontendConfigResponse.


        :param user_volume_ops_enabled: The user_volume_ops_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :type user_volume_ops_enabled: bool
        """

        self._user_volume_ops_enabled = user_volume_ops_enabled

    @property
    def vessl_storage_enabled(self):
        """Gets the vessl_storage_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501


        :return: The vessl_storage_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :rtype: bool
        """
        return self._vessl_storage_enabled

    @vessl_storage_enabled.setter
    def vessl_storage_enabled(self, vessl_storage_enabled):
        """Sets the vessl_storage_enabled of this ClientconfigFrontendConfigResponse.


        :param vessl_storage_enabled: The vessl_storage_enabled of this ClientconfigFrontendConfigResponse.  # noqa: E501
        :type vessl_storage_enabled: bool
        """
        if self.local_vars_configuration.client_side_validation and vessl_storage_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `vessl_storage_enabled`, must not be `None`")  # noqa: E501

        self._vessl_storage_enabled = vessl_storage_enabled

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClientconfigFrontendConfigResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ClientconfigFrontendConfigResponse):
            return True

        return self.to_dict() != other.to_dict()
